import sys
from example_interfaces.srv import SetBool
import rclpy
from rclpy.node import Node


class VolControlClientAsync(Node):

    def __init__(self):
        super().__init__('volControl_client_async')
        self.cli = self.create_client(SetBool, 'volControl')
        while not self.cli.wait_for_service(timeout_sec=1.0):
            self.get_logger().info('service not available, waiting again...')
        self.req = SetBool.Request()

    def send_request(self):
        self.req.data = True if int(sys.argv[1]) == 1 else False
        self.future = self.cli.call_async(self.req)


def main(args=None):
    if len(sys.argv) != 2:
        print("usage: arg must equal 2")
        return 1

    if int(sys.argv[1]) != 0 and int(sys.argv[1]) != 1:
        print("usage(up|down): 1|0 ")
        return 1

    rclpy.init(args=args)
    volctrl_client = VolControlClientAsync()
    volctrl_client.send_request()

    while rclpy.ok():
        rclpy.spin_once(volctrl_client)
        if volctrl_client.future.done():
            try:
                response = volctrl_client.future.result()
            except Exception as e:
                volctrl_client.get_logger().info(
                    'Service call failed %r' % (e,))
            else:
                volctrl_client.get_logger().info(
                    'Result of server: for %d' % response.success)
            break

    volctrl_client.destroy_node()
    rclpy.shutdown()


if __name__ == '__main__':
    main()
