#include "rclcpp/rclcpp.hpp"
#include "example_interfaces/srv/set_bool.hpp"

#include <chrono>
#include <cstdlib>
#include <memory>

using namespace std::chrono_literals;

int main(int argc, char **argv)
{
	rclcpp::init(argc, argv);

	if (argc != 2) 
	{
		RCLCPP_INFO(rclcpp::get_logger("rclcpp"), "usage: arg must equal 2");
		return 1;
	}

	if (atoi(argv[1]) != 0 && atoi(argv[1]) != 1)
	{
		RCLCPP_INFO(rclcpp::get_logger("rclcpp"), "usage(add|decrease): 1|0 ");
		return 1;
	}

	//创建名为volume_control_client的节点
	std::shared_ptr<rclcpp::Node> node = rclcpp::Node::make_shared("volume_control_client");

	//创建名为volume_control的客户端，需与volume_server创建的service同名
	rclcpp::Client<example_interfaces::srv::SetBool>::SharedPtr client =
	node->create_client<example_interfaces::srv::SetBool>("volume_control");

	//采集request数据
	auto request = std::make_shared<example_interfaces::srv::SetBool::Request>();
	request->data = atoi(argv[1]);

	//search for service
	while (!client->wait_for_service(1s)) 
	{
		if (!rclcpp::ok()) 
		{
			RCLCPP_ERROR(rclcpp::get_logger("rclcpp"), "Interrupted while waiting for the service. Exiting.");
			return 0;
		}
		RCLCPP_INFO(rclcpp::get_logger("rclcpp"), "service not available, waiting again...");
	}

	//发送request
	auto result = client->async_send_request(request);
	
	// Wait for the result.
	if (rclcpp::spin_until_future_complete(node, result) == rclcpp::FutureReturnCode::SUCCESS)
	{
		RCLCPP_INFO(rclcpp::get_logger("rclcpp"), "Res: %ld", result.get()->success);
	} 
	else 
	{
		RCLCPP_ERROR(rclcpp::get_logger("rclcpp"), "Failed to call service volume_control");
	}

	rclcpp::shutdown();
	return 0;
}